@@ -1,6 +1,6 @@
 # help.py - help data for mercurial
 #
-# Copyright 2006 Matt Mackall <mpm@selenic.com>
+# Copyright 2006 Olivia Mackall <olivia@selenic.com>
 #
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
@@ -364,6 +364,11 @@ internalstable = sorted(
             _(b'Config Registrar'),
             loaddoc(b'config', subdir=b'internals'),
         ),
+        (
+            [b'dirstate-v2'],
+            _(b'dirstate-v2 file format'),
+            loaddoc(b'dirstate-v2', subdir=b'internals'),
+        ),
         (
             [b'extensions', b'extension'],
             _(b'Extension API'),
@@ -539,6 +544,12 @@ helptable = sorted(
             loaddoc(b'phases'),
             TOPIC_CATEGORY_CONCEPTS,
         ),
+        (
+            [b"evolution"],
+            _(b"Safely rewriting history (EXPERIMENTAL)"),
+            loaddoc(b'evolution'),
+            TOPIC_CATEGORY_CONCEPTS,
+        ),
         (
             [b'scripting'],
             _(b'Using Mercurial from scripts and automation'),
@@ -829,10 +840,11 @@ def help_(
         def appendcmds(cmds):
             cmds = sorted(cmds)
             for c in cmds:
+                display_cmd = c
                 if ui.verbose:
-                    rst.append(b" :%s: %s\n" % (b', '.join(syns[c]), h[c]))
-                else:
-                    rst.append(b' :%s: %s\n' % (c, h[c]))
+                    display_cmd = b', '.join(syns[c])
+                display_cmd = display_cmd.replace(b':', br'\:')
+                rst.append(b' :%s: %s\n' % (display_cmd, h[c]))
 
         if name in (b'shortlist', b'debug'):
             # List without categories.
